diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index 4c8569fef8fceab47cbe6682af00d3265031f7bf..d89f1f60605ab620649df172bd0f613f36a58f9d 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -1,27 +1,27 @@
 pylint:
-  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:centos7
+  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:x86_64-el9
   tags:
     - cvmfs
   script:
     - ./run_pylint.sh || exit 1
 
 unit_tests:
-  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:centos7
+  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:x86_64-el9
   tags:
     - cvmfs
   script:
     - ./run_unit_tests.sh gitlab || exit 1
 
 compilation:
-  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:centos7
+  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:x86_64-el9
   tags:
     - cvmfs
   script:
-    - source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-10-00-00
+    - source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-11-01-00
     - python -m compileall .
 
 basictest:
-  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:centos7
+  image: gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:x86_64-el9
   tags:
     - cvmfs
   script:
diff --git a/DeploymentTest/tbed.test.bash b/DeploymentTest/tbed.test.bash
index e086ea45df178d70ce3a73495a3e7f2a102d507a..55dc55eb864c929cd20abfaa9692842daf22799a 100755
--- a/DeploymentTest/tbed.test.bash
+++ b/DeploymentTest/tbed.test.bash
@@ -71,7 +71,7 @@ fi
 
 echo "Starting CastorScript with config file: $CS_CONFIG_FILE"
 if ! [ -v TDAQ_LCG_RELEASE ]; then
-    source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-10-00-00
+    source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-11-01-00
 fi
 python -u $SOURCE_DIR/Script/CastorScript.py $CS_CONFIG_FILE &>$TMP_DIR/logs/stdouterr &
 
diff --git a/point1.deployment.sh b/point1.deployment.sh
index c1491397e9cd2762a4fb384212a2ccd1751ec855..2b7caa7e6aa34ffa2e02748fffdfb73df6baf794 100755
--- a/point1.deployment.sh
+++ b/point1.deployment.sh
@@ -44,7 +44,7 @@ rm run_docker_container.sh run_pylint.sh run_unit_tests.sh || err "cannot delete
 # compile with python interpreter from TDAQ
 # execute in subshell to avoid importing TDAQ stuffs in here
 (
-  source /sw/tdaq/setup/setup_tdaq-09-04-00.sh
+  source /sw/tdaq/setup/setup_tdaq-11-01-00.sh
   python -m compileall . || err "compiling"
 )
 
diff --git a/run_pylint.sh b/run_pylint.sh
index 6331731c138c57e4c1c82fad065e7ef494406905..82df7e04a49f49883807d9eb31ff1f4b63d7e2b6 100755
--- a/run_pylint.sh
+++ b/run_pylint.sh
@@ -1,10 +1,8 @@
 #!/bin/bash
 cd `dirname $0`
 
-# NOT MIGRATED TO tdaq-09-04-00: pylint from LCG 101 does not work:
-# https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC2920656
 if ! [ -v TDAQ_LCG_RELEASE ]; then
-    source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-10-00-00
+    source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-11-01-00
 fi
 
 /cvmfs/sft.cern.ch/lcg/views/$TDAQ_LCG_RELEASE/$CMTCONFIG/bin/pylint $(find . -name '*.py' -a -not -name config.py)
diff --git a/run_unit_tests.sh b/run_unit_tests.sh
index f0b4c170fa85b9e13bb2389938c44a61a5568837..eaa52a8307cbc2803adadfe9087bf7eb5662ae74 100755
--- a/run_unit_tests.sh
+++ b/run_unit_tests.sh
@@ -2,7 +2,7 @@
 cd `dirname $0`
 
 if ! [ -v TDAQ_LCG_RELEASE ]; then
-    source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-10-00-00
+    source /cvmfs/atlas.cern.ch/repo/sw/tdaq/tools/cmake_tdaq/bin/cm_setup.sh tdaq-11-01-00
 fi
 
 PATTERN='*_[Tt]est.py'
diff --git a/script_setup.sh b/script_setup.sh
index 6b8ed142db18cf4e41e50ed9071bbf52d6684214..ebc6ac714225f50abf9201b25fdfe58d86321f2b 100755
--- a/script_setup.sh
+++ b/script_setup.sh
@@ -1,5 +1,5 @@
 #!/bin/bash
-TDAQ_RELEASE=tdaq-10-00-00
+TDAQ_RELEASE=tdaq-11-01-00
 
 echo "setting up environment for centos, tdaq release: $TDAQ_RELEASE"
 source /sw/tdaq/setup/setup_$TDAQ_RELEASE.sh
diff --git a/run_docker_container.sh b/run_docker_container.sh
index 59f6520f3829fc6b0d0a848b600343f50c5b1a8b..0bf466a8a594a18da5bf02a770d5426a403feaaa 100755
--- a/run_docker_container.sh
+++ b/run_docker_container.sh
@@ -16,6 +16,6 @@
 # 7 and run the centos7 image,
 # 8 when started, run the run_unit_tests script in bash
 # 1      2   3                4                       5                                          6         7                                                           8
 # docker run -it --privileged -v `pwd`:`pwd` -w `pwd` -v /cvmfs:/cvmfs:shared,ro --rm=true gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:centos7 bash ./run_unit_tests.sh
 # or without running the script:
-docker run -it --privileged -v `pwd`:`pwd` -w `pwd` -v /cvmfs:/cvmfs:shared,ro --rm=true gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:centos7 bash
+docker run -it --privileged -v `pwd`:`pwd` -w `pwd` -v /cvmfs:/cvmfs:shared,ro --rm=true gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:x86_64-el9 bash
@@ -16,6 +16,6 @@
 # 8 when started, run the run_unit_tests script in bash
 # 1      2   3                4                       5                                          6         7                                                           8
-# docker run -it --privileged -v `pwd`:`pwd` -w `pwd` -v /cvmfs:/cvmfs:shared,ro --rm=true gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:centos7 bash ./run_unit_tests.sh
+# docker run -it --privileged -v `pwd`:`pwd` -w `pwd` -v /cvmfs:/cvmfs:shared,ro --rm=true gitlab-registry.cern.ch/atlas-tdaq-software/tdaq_ci:x86_64-el9 bash ./run_unit_tests.sh
 # or without running the script: